@@ -1,4 +1,5 @@
 # coding=utf-8
+import re
 from itertools import chain
 
 from django import template
@@ -7,6 +8,7 @@ from django.conf import settings
 from django.contrib import admin
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
+from django.urls import reverse
 from django.utils.translation import gettext as _, gettext_lazy
 
 register = template.Library()
@@ -178,8 +180,8 @@ def title_icon_admin():
 @register.simple_tag()
 def url_account():
     try:
-        list = settings.AUTH_USER_MODEL.split('.')
-        _namespace_url = list
+        _namespace_url = re.sub('\.', ':', settings.TESTE)
+        reverse(_namespace_url)
     except:
         _namespace_url = 'admin:auth_user_change'
     return _namespace_url
\ No newline at end of file
